<!-- SPDX-FileCopyrightText: 2025 Semiotic AI, Inc. -->
<!-- SPDX-License-Identifier: MIT -->

# API Reference

## Overview

The Agentium SDK is organized into several modules:

| Module | Description |
|--------|-------------|
| [Client](client.md) | `AgentiumClient` for API interactions |
| [Types](types.md) | Response dataclasses |
| [Native Functions](native.md) | Rust-powered cryptographic operations |
| [Exceptions](exceptions.md) | Error types |

## Top-Level Functions

### Google Sign-In

::: agentium_sdk.connect_google

::: agentium_sdk.connect_google_sync

### Wallet Sign-In

::: agentium_sdk.connect_wallet

::: agentium_sdk.connect_wallet_sync
